Clazz.declarePackage("JU");
Clazz.load(["java.lang.RuntimeException"], "JU.JSONException", null, function(){
var c$ = Clazz.declareType(JU, "JSONException", RuntimeException);
});
;//5.0.1-v7 Wed May 27 19:27:27 CDT 2026
